@@ -433,7 +433,12 @@ AddNotificationChannelResponseTypeDef = TypedDict(
 
 DescribeAccountHealthResponseTypeDef = TypedDict(
     "DescribeAccountHealthResponseTypeDef",
-    {"OpenReactiveInsights": int, "OpenProactiveInsights": int, "MetricsAnalyzed": int},
+    {
+        "OpenReactiveInsights": int,
+        "OpenProactiveInsights": int,
+        "MetricsAnalyzed": int,
+        "ResourceHours": int,
+    },
 )
 
 DescribeAccountOverviewResponseTypeDef = TypedDict(
